"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.CreateComment = CreateComment;

var _core = require("@material-ui/core");

var _react = _interopRequireWildcard(require("react"));

var _hooks = require("../../hooks");

var _ = require(".");

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const useStyles = (0, _core.makeStyles)(theme => {
  return (0, _core.createStyles)({
    buttonContainer: {
      display: 'flex',
      flexDirection: 'row-reverse'
    },
    form: {
      width: '100%',
      display: 'flex'
    },
    activePin: {
      color: theme.palette.primary.light
    }
  });
});
/**
 * Represents a comment creator component
 */

function CreateComment() {
  var _viewerState$rotation, _viewerState$rotation2;

  const classes = useStyles();
  const [errorMessage, setErrorMessage] = (0, _react.useState)();
  const [createCommentValue, setCreateCommentValue] = (0, _react.useState)('');
  const localization = (0, _hooks.useLocalization)();
  const commentState = (0, _hooks.useCommentState)();
  const viewerState = (0, _hooks.useViewerState)();
  const api = (0, _hooks.useDocumentViewerApi)();
  const {
    documentData
  } = (0, _hooks.useDocumentData)();
  const pageRotation = ((_viewerState$rotation = viewerState.rotation) === null || _viewerState$rotation === void 0 ? void 0 : (_viewerState$rotation2 = _viewerState$rotation.find(rotation => rotation.pageNum === viewerState.activePage)) === null || _viewerState$rotation2 === void 0 ? void 0 : _viewerState$rotation2.degree) || 0;
  const createComment = (0, _react.useCallback)(text => {
    if (!commentState.draft) {
      return;
    }

    try {
      api.commentActions.addPreviewComment({
        document: documentData,
        comment: { ...commentState.draft,
          text,
          page: commentState.draft.page
        },
        abortController: new AbortController()
      });
    } catch (error) {
      console.log(error);
    }
  }, [api.commentActions, commentState.draft, documentData]);
  const clearState = (0, _react.useCallback)(() => {
    commentState.setDraft(undefined);
    viewerState.updateState({
      isPlacingCommentMarker: false,
      isCreateCommentActive: !viewerState.isCreateCommentActive
    });
    setCreateCommentValue('');
    setErrorMessage(undefined);
  }, [commentState, viewerState]);
  const validate = (0, _react.useCallback)(() => {
    if (!createCommentValue) {
      return localization.inputRequiredError;
    }

    if (!commentState.draft) {
      return localization.markerRequiredError;
    }

    return undefined;
  }, [commentState.draft, createCommentValue, localization.inputRequiredError, localization.markerRequiredError]);
  const handleSubmit = (0, _react.useCallback)(event => {
    event.preventDefault();
    const errorText = validate();

    if (errorText) {
      setErrorMessage(errorText);
      return;
    }

    createComment(createCommentValue);
    clearState();
  }, [clearState, createComment, createCommentValue, validate]);

  const handleOnChange = e => {
    setCreateCommentValue(e.target.value);
    setErrorMessage(undefined);
  };

  if (!viewerState.isCreateCommentActive) {
    return /*#__PURE__*/_react.default.createElement(_core.Button, {
      disabled: pageRotation !== 0,
      color: "primary",
      onClick: () => viewerState.updateState({
        isCreateCommentActive: !viewerState.isCreateCommentActive
      })
    }, localization.addComment);
  }

  return /*#__PURE__*/_react.default.createElement("form", {
    className: classes.form,
    onSubmit: handleSubmit
  }, /*#__PURE__*/_react.default.createElement(_core.FormControl, {
    fullWidth: true,
    error: !!errorMessage
  }, /*#__PURE__*/_react.default.createElement(_core.TextField, {
    id: "comment-input",
    multiline: true,
    label: localization.commentInputPlaceholder,
    margin: "normal",
    variant: "filled",
    value: createCommentValue,
    onChange: handleOnChange,
    InputProps: {
      endAdornment: /*#__PURE__*/_react.default.createElement(_core.InputAdornment, {
        position: "end"
      }, /*#__PURE__*/_react.default.createElement(_core.Tooltip, {
        placement: "top",
        title: localization.markerTooltip
      }, /*#__PURE__*/_react.default.createElement(_core.IconButton, {
        "aria-label": "Toggle",
        onClick: () => viewerState.updateState({
          activeShapePlacing: 'none',
          isPlacingCommentMarker: !viewerState.isPlacingCommentMarker
        })
      }, /*#__PURE__*/_react.default.createElement(_.PushPinIcon, {
        isPlacingMarker: viewerState.isPlacingCommentMarker,
        viewBox: "0 0 100 125"
      }))))
    }
  }), errorMessage ? /*#__PURE__*/_react.default.createElement(_core.FormHelperText, {
    id: "component-error-text"
  }, errorMessage) : null, /*#__PURE__*/_react.default.createElement("div", {
    className: classes.buttonContainer
  }, /*#__PURE__*/_react.default.createElement(_core.Button, {
    style: {
      alignSelf: 'flex-end'
    },
    fullWidth: false,
    color: "primary",
    variant: "text",
    type: "submit"
  }, localization.submit), /*#__PURE__*/_react.default.createElement(_core.Button, {
    onClick: clearState,
    style: {
      alignSelf: 'flex-end'
    },
    fullWidth: false,
    variant: "text"
  }, localization.cancelButton))));
}
//# sourceMappingURL=create-comment.js.map