"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Page = exports.ANNOTATION_EXTRA_VALUES = void 0;

var _core = require("@material-ui/core");

var _clsx = _interopRequireDefault(require("clsx"));

var _react = _interopRequireWildcard(require("react"));

var _hooks = require("../hooks");

var _services = require("../services");

var _documentViewerLayout = require("./document-viewer-layout");

var _shapes = require("./shapes");

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const ANNOTATION_EXTRA_VALUES = {
  text: '',
  lineHeight: 40,
  fontBold: 400,
  fontColor: '#000000',
  fontFamily: 'arial',
  fontItalic: false,
  fontSize: 40
};
exports.ANNOTATION_EXTRA_VALUES = ANNOTATION_EXTRA_VALUES;
const useStyles = (0, _core.makeStyles)(() => {
  return (0, _core.createStyles)({
    page: {
      padding: 0,
      overflow: 'hidden',
      width: ({
        page
      }) => page.Width,
      height: ({
        page
      }) => page.Height,
      position: 'relative'
    },
    image: {
      display: 'flex',
      justifyContent: 'center'
    },
    isPlacingShape: {
      cursor: 'crosshair'
    },
    draftShapeContainer: {
      position: 'absolute',
      top: 0,
      left: 0,
      width: '100%',
      height: '100%',
      zIndex: 1
    }
  });
});
/**
 * Defined the component's own properties
 */

const Page = props => {
  var _page$image2, _page$image3, _viewerState$rotation, _viewerState$rotation2, _page$image4, _page$image5, _page$image8, _page$image9;

  const classes = useStyles(props);
  const viewerState = (0, _hooks.useViewerState)();
  const page = (0, _hooks.usePreviewImage)(props.page.Index);
  const commentState = (0, _hooks.useCommentState)();
  const [mouseIsDown, setMouseIsDown] = (0, _react.useState)(false);
  const [startX, setStartX] = (0, _react.useState)(0);
  const [startY, setStartY] = (0, _react.useState)(0);
  const [startOffsetX, setStartOffsetX] = (0, _react.useState)(0);
  const [startOffsetY, setStartOffsetY] = (0, _react.useState)(0);
  const [draftWidth, setdraftWidth] = (0, _react.useState)(0);
  const [draftHeight, setdraftHeight] = (0, _react.useState)(0);
  const [scrollX, setScrollX] = (0, _react.useState)(0);
  const [scrollY, setScrollY] = (0, _react.useState)(0);
  const [scrollOffsetX, setScrollOffsetX] = (0, _react.useState)(0);
  const [scrollOffsetY, setScrollOffsetY] = (0, _react.useState)(0);
  const {
    documentData,
    updateDocumentData
  } = (0, _hooks.useDocumentData)();
  const imageRatio = (0, _react.useMemo)(() => {
    var _page$image;

    return props.page.Height / (((_page$image = page.image) === null || _page$image === void 0 ? void 0 : _page$image.Height) || 1);
  }, [props.page.Height, (_page$image2 = page.image) === null || _page$image2 === void 0 ? void 0 : _page$image2.Height]);
  const isActive = page.image && viewerState.activePage === page.image.Index;
  const imgUrl = page.image && ((_page$image3 = page.image) === null || _page$image3 === void 0 ? void 0 : _page$image3.PreviewImageUrl) || '';

  const imageRotation = _services.ImageUtil.normalizeDegrees(((_viewerState$rotation = viewerState.rotation) === null || _viewerState$rotation === void 0 ? void 0 : (_viewerState$rotation2 = _viewerState$rotation.find(rotation => rotation.pageNum === props.page.Index)) === null || _viewerState$rotation2 === void 0 ? void 0 : _viewerState$rotation2.degree) || 0);

  const imageRotationRads = imageRotation % 180 * Math.PI / 180;

  const boundingBox = _services.ImageUtil.getRotatedBoundingBoxSize({
    width: ((_page$image4 = page.image) === null || _page$image4 === void 0 ? void 0 : _page$image4.Width) || 0,
    height: ((_page$image5 = page.image) === null || _page$image5 === void 0 ? void 0 : _page$image5.Height) || 0
  }, imageRotation);

  const diffHeight = Math.sin(imageRotationRads) * ((props.page.Height - props.page.Width) / 2);
  const imageTransform = `translateY(${diffHeight}px) rotate(${imageRotation}deg)`;
  const reCalculateDraftShape = (0, _react.useCallback)(ev => {
    const compareNumbers = (a, b) => a - b;

    const pageBoundings = {
      left: Math.max(viewerState.pagesRects[props.visiblePagesIndex].pageRect.left, viewerState.boxPosition.left),
      right: Math.min(viewerState.pagesRects[props.visiblePagesIndex].pageRect.right, viewerState.boxPosition.right),
      bottom: Math.min(viewerState.pagesRects[props.visiblePagesIndex].pageRect.bottom, viewerState.boxPosition.bottom),
      top: Math.max(viewerState.pagesRects[props.visiblePagesIndex].pageRect.top, viewerState.boxPosition.top)
    };
    const endX = ([pageBoundings.left, pageBoundings.right, ev.pageX].sort(compareNumbers)[1] + scrollOffsetX) / imageRatio;
    const endY = ([pageBoundings.bottom, pageBoundings.top, ev.pageY].sort(compareNumbers)[1] + scrollOffsetY) / imageRatio;
    return {
      endX,
      endY
    };
  }, [imageRatio, props.visiblePagesIndex, scrollOffsetX, scrollOffsetY, viewerState.boxPosition.bottom, viewerState.boxPosition.left, viewerState.boxPosition.right, viewerState.boxPosition.top, viewerState.pagesRects]);
  (0, _react.useEffect)(() => {
    var _props$pageContainerR;

    const handleGlobalScroll = ev => {
      if (ev.currentTarget) {
        if (viewerState.activeShapePlacing !== 'none' && mouseIsDown) {
          setScrollOffsetX(ev.currentTarget.scrollLeft - scrollX);
          setScrollOffsetY(ev.currentTarget.scrollTop - scrollY);
        } else {
          setScrollX(ev.currentTarget.scrollLeft || 0);
          setScrollY(ev.currentTarget.scrollTop || 0);
          setScrollOffsetX(0);
          setScrollOffsetY(0);
        }
      }
    };

    (_props$pageContainerR = props.pageContainerRef) === null || _props$pageContainerR === void 0 ? void 0 : _props$pageContainerR.addEventListener('scroll', handleGlobalScroll);
    return () => {
      var _props$pageContainerR2;

      (_props$pageContainerR2 = props.pageContainerRef) === null || _props$pageContainerR2 === void 0 ? void 0 : _props$pageContainerR2.removeEventListener('scroll', handleGlobalScroll);
    };
  }, [mouseIsDown, props.pageContainerRef, scrollX, scrollY, viewerState.activeShapePlacing]);
  (0, _react.useEffect)(() => {
    const handleGlobalMouseMove = ev => {
      if (viewerState.activeShapePlacing !== 'none' && mouseIsDown && viewerState.pagesRects[props.visiblePagesIndex] && (viewerState.boxPosition.bottom || viewerState.boxPosition.left || viewerState.boxPosition.right || viewerState.boxPosition.top)) {
        const {
          endX,
          endY
        } = reCalculateDraftShape(ev);
        setdraftHeight(endY - startY);
        setdraftWidth(endX - startX);
      }
    };

    document.addEventListener('mousemove', handleGlobalMouseMove);
    return () => {
      document.removeEventListener('mousemove', handleGlobalMouseMove);
    };
  }, [mouseIsDown, props.visiblePagesIndex, reCalculateDraftShape, startX, startY, viewerState.activeShapePlacing, viewerState.boxPosition.bottom, viewerState.boxPosition.left, viewerState.boxPosition.right, viewerState.boxPosition.top, viewerState.pagesRects]);
  (0, _react.useEffect)(() => {
    const handleGlobalMouseUp = ev => {
      if (mouseIsDown && (viewerState.boxPosition.bottom || viewerState.boxPosition.left || viewerState.boxPosition.right || viewerState.boxPosition.top)) {
        setMouseIsDown(false);
        setdraftHeight(0);
        setdraftWidth(0);
        const {
          endX,
          endY
        } = reCalculateDraftShape(ev);

        if (endY - startY > 0 && endX - startX > 0) {
          switch (viewerState.activeShapePlacing) {
            case 'annotation':
              documentData.shapes.annotations.push({
                h: endY - startY,
                w: endX - startX,
                x: startOffsetX,
                y: startOffsetY,
                imageIndex: props.page.Index,
                guid: `a-${startX}-${startY}`,
                ...ANNOTATION_EXTRA_VALUES
              });
              updateDocumentData(documentData);
              viewerState.updateState({
                hasChanges: true,
                activeShapePlacing: 'none',
                showShapes: true
              });
              break;

            case 'highlight':
              documentData.shapes.highlights.push({
                h: endY - startY,
                w: endX - startX,
                x: startOffsetX,
                y: startOffsetY,
                imageIndex: props.page.Index,
                guid: `h-${startX}-${startY}`
              });
              updateDocumentData(documentData);
              viewerState.updateState({
                hasChanges: true,
                activeShapePlacing: 'none',
                showShapes: true
              });
              break;

            case 'redaction':
              documentData.shapes.redactions.push({
                h: endY - startY,
                w: endX - startX,
                x: startOffsetX,
                y: startOffsetY,
                imageIndex: props.page.Index,
                guid: `r-${startX}-${startY}`
              });
              updateDocumentData(documentData);
              viewerState.updateState({
                hasChanges: true,
                activeShapePlacing: 'none',
                showRedaction: true
              });
              break;

            default:
              break;
          }
        }

        setStartX(0);
        setStartY(0);
        setScrollX(scrollOffsetX + scrollX);
        setScrollY(scrollOffsetY + scrollY);
        setScrollOffsetX(0);
        setScrollOffsetY(0);
      }
    };

    document.addEventListener('mouseup', handleGlobalMouseUp);
    return () => {
      document.removeEventListener('mouseup', handleGlobalMouseUp);
    };
  }, [documentData, mouseIsDown, props.page.Index, reCalculateDraftShape, scrollOffsetX, scrollOffsetY, scrollX, scrollY, startOffsetX, startOffsetY, startX, startY, updateDocumentData, viewerState]);
  const handleMarkerPlacement = (0, _react.useCallback)(event => {
    var _page$image6, _page$image7;

    if (imageRotation !== 0) {
      viewerState.updateState({
        isPlacingCommentMarker: false
      });
    }

    const xCoord = event.nativeEvent.offsetX / imageRatio;
    const yCoord = event.nativeEvent.offsetY / (props.page.Width / (((_page$image6 = page.image) === null || _page$image6 === void 0 ? void 0 : _page$image6.Width) || 1));

    if (!viewerState.isPlacingCommentMarker || xCoord <= _shapes.MARKER_SIZE || yCoord <= _shapes.MARKER_SIZE) {
      return;
    }

    const newCommentMarker = {
      x: `${xCoord - _shapes.MARKER_SIZE}`,
      y: `${yCoord - _shapes.MARKER_SIZE}`,
      id: 'draft',
      page: ((_page$image7 = page.image) === null || _page$image7 === void 0 ? void 0 : _page$image7.Index) || viewerState.activePage
    };
    commentState.setDraft(newCommentMarker);
  }, [commentState, imageRatio, imageRotation, (_page$image8 = page.image) === null || _page$image8 === void 0 ? void 0 : _page$image8.Index, (_page$image9 = page.image) === null || _page$image9 === void 0 ? void 0 : _page$image9.Width, props.page.Width, viewerState]);

  const handleMouseDown = ev => {
    if (imageRotation !== 0) {
      viewerState.updateState({
        activeShapePlacing: 'none'
      });
    }

    setMouseIsDown(true);
    setStartX(ev.nativeEvent.pageX / imageRatio);
    setStartY(ev.nativeEvent.pageY / imageRatio);
    setStartOffsetX((ev.nativeEvent.pageX - viewerState.pagesRects[props.visiblePagesIndex].pageRect.left) / imageRatio);
    setStartOffsetY((ev.nativeEvent.pageY - viewerState.pagesRects[props.visiblePagesIndex].pageRect.top) / imageRatio);
  };

  return /*#__PURE__*/_react.default.createElement(_core.Paper, {
    elevation: isActive ? 8 : 2,
    className: _documentViewerLayout.PAGE_NAME,
    style: {
      margin: _documentViewerLayout.PAGE_PADDING
    }
  }, /*#__PURE__*/_react.default.createElement("div", {
    className: (0, _clsx.default)(classes.page, {
      [classes.isPlacingShape]: viewerState.activeShapePlacing !== 'none'
    }),
    onClick: ev => {
      viewerState.isPlacingCommentMarker ? handleMarkerPlacement(ev) : props.onClick(ev);
    },
    onMouseDown: ev => {
      viewerState.activeShapePlacing !== 'none' && !mouseIsDown && handleMouseDown(ev);
    }
  }, page.image && /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_shapes.ShapesWidget, {
    imageRotation: imageRotation,
    zoomRatioStanding: props.page.Height / page.image.Height,
    zoomRatioLying: props.page.Width / page.image.Height,
    page: page.image,
    visiblePagesIndex: props.visiblePagesIndex,
    pageContainerRef: props.pageContainerRef
  }), mouseIsDown && /*#__PURE__*/_react.default.createElement("div", {
    className: classes.draftShapeContainer
  }, /*#__PURE__*/_react.default.createElement(_shapes.ShapeDraft, {
    dimensions: {
      top: startOffsetY * (props.page.Height / page.image.Height),
      left: startOffsetX * (props.page.Height / page.image.Height),
      height: draftHeight * (props.page.Height / page.image.Height),
      width: draftWidth * (props.page.Height / page.image.Height)
    }
  }))), /*#__PURE__*/_react.default.createElement("span", {
    className: classes.image
  }, imgUrl ? /*#__PURE__*/_react.default.createElement("img", {
    src: `${imgUrl}${viewerState.showWatermark ? '?watermark=true' : ''}`,
    alt: "",
    style: {
      transition: 'transform .1s ease-in-out',
      width: `${100 * boundingBox.zoomRatio}%`,
      height: `${100 * boundingBox.zoomRatio}%`,
      transform: imageTransform,
      userSelect: 'none'
    }
  }) : /*#__PURE__*/_react.default.createElement(_core.CircularProgress, {
    style: {
      marginTop: '50%'
    }
  }))));
};

exports.Page = Page;
//# sourceMappingURL=page.js.map