"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.AnnotationWrapper = void 0;

var _core = require("@material-ui/core");

var _react = _interopRequireWildcard(require("react"));

var _hooks = require("../../hooks");

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const useStyles = (0, _core.makeStyles)(() => (0, _core.createStyles)({
  root: {
    position: 'absolute',
    resize: ({
      permissions,
      rotationDegree
    }) => `${permissions.canEdit && rotationDegree === 0 ? 'both' : 'none'}`,
    overflow: 'hidden',
    backgroundColor: 'blanchedalmond',
    lineHeight: ({
      shape,
      zoomRatio
    }) => `${shape.lineHeight * zoomRatio}px`,
    fontWeight: ({
      shape
    }) => shape.fontBold,
    color: ({
      shape
    }) => shape.fontColor,
    fontFamily: ({
      shape
    }) => shape.fontFamily,
    fontSize: ({
      shape,
      zoomRatio
    }) => `${shape.fontSize * zoomRatio}px`,
    fontStyle: ({
      shape
    }) => shape.fontItalic ? 'italic' : 'normal',
    boxShadow: ({
      zoomRatio
    }) => `${5 * zoomRatio}px ${5 * zoomRatio}px ${15 * zoomRatio}px rgba(0,0,0,.3)`,
    padding: ({
      zoomRatio
    }) => `${10 * zoomRatio}pt`,
    boxSizing: 'border-box'
  }
}));
/**
 * Return a styled annotation wrapper component
 * @param permissions The permissions of the user
 * @param shape The arguments of the annotation
 * @param zoomRatio The ratio of the origina and virtual page
 * @param dimensions The dimensions of the annotation
 * @param onDragStart Function triggered on drag event
 * @param onResized Function triggered on resize event
 * @param onRightClick Function triggered on right click
 * @param renderChildren Function what returns the wrapped components
 * @returns styled annotation wrapper component
 */

const AnnotationWrapper = props => {
  const permissions = (0, _hooks.useDocumentPermissions)();
  const classes = useStyles({ ...props,
    permissions
  });
  const annotationElement = (0, _react.useRef)(null);
  const viewerState = (0, _hooks.useViewerState)();
  const {
    updateState
  } = viewerState;
  (0, _react.useEffect)(() => {
    const handleGlobalMouseUp = () => {
      if (viewerState.currentlyResizedElementId === props.shape.guid) {
        var _annotationElement$cu;

        updateState({
          currentlyResizedElementId: undefined
        });
        const newSize = props.onResized((_annotationElement$cu = annotationElement.current) === null || _annotationElement$cu === void 0 ? void 0 : _annotationElement$cu.getClientRects()[0]);

        if (annotationElement.current && newSize) {
          annotationElement.current.style.width = `${newSize.w * props.zoomRatio}px`;
          annotationElement.current.style.height = `${newSize.h * props.zoomRatio}px`;
        }
      }
    };

    document.addEventListener('mouseup', handleGlobalMouseUp);
    return () => {
      document.removeEventListener('mouseup', handleGlobalMouseUp);
    };
  }, [props, updateState, viewerState.currentlyResizedElementId]);
  (0, _react.useEffect)(() => {
    const mutationObserver = new MutationObserver(mutations => {
      mutations.forEach(mutation => {
        if (mutation.attributeName === 'style') {
          updateState({
            currentlyResizedElementId: props.shape.guid
          });
        }
      });
    });
    annotationElement.current && mutationObserver.observe(annotationElement.current, {
      attributes: true
    });
    return () => mutationObserver.disconnect();
  }, [props.shape.guid, updateState]);
  return /*#__PURE__*/_react.default.createElement("div", {
    className: classes.root,
    tabIndex: 0,
    draggable: permissions.canEdit,
    onDragStart: props.onDragStart,
    onContextMenu: props.onRightClick,
    style: {
      top: props.dimensions.top,
      left: props.dimensions.left,
      width: `${props.dimensions.width}px`,
      height: `${props.dimensions.height}px`
    },
    ref: annotationElement
  }, props.children);
};

exports.AnnotationWrapper = AnnotationWrapper;
//# sourceMappingURL=annotation-wrapper.js.map