"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ShapeHighlight = void 0;

var _core = require("@material-ui/core");

var _yellow = _interopRequireDefault(require("@material-ui/core/colors/yellow.js"));

var _icons = require("@material-ui/icons");

var _react = _interopRequireWildcard(require("react"));

var _ = require("../..");

var _hooks = require("../../hooks");

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const useStyles = (0, _core.makeStyles)(theme => (0, _core.createStyles)({
  root: {
    position: 'absolute',
    resize: ({
      permissions,
      rotationDegree
    }) => permissions.canEdit && rotationDegree === 0 ? 'both' : 'none',
    overflow: 'auto',
    backgroundColor: _yellow.default[600],
    opacity: 0.5
  },
  button: {
    backgroundColor: theme.palette.error.light
  }
}));
/**
 * Return a styled highlight component
 * @param shape Shape attributes
 * @param permissions Permissions of the current user
 * @param dimensions Shape dimensions
 * @param zoomRatio Zoom ratio
 * @param onDragStart Function triggered on drag event
 * @param onResized Function triggered on resized event
 * @param removeShape Function triggered on delete
 * @returns styled highlight component
 */

const ShapeHighlight = props => {
  const permissions = (0, _hooks.useDocumentPermissions)();
  const classes = useStyles({ ...props,
    permissions
  });
  const localization = (0, _.useLocalization)();
  const [anchorEl, setAnchorEl] = (0, _react.useState)(null);
  const open = Boolean(anchorEl);
  const id = open ? 'highlight-delete' : undefined;
  const highlightElement = (0, _react.useRef)(null);
  const viewerState = (0, _hooks.useViewerState)();
  const {
    updateState
  } = viewerState;
  (0, _react.useEffect)(() => {
    const handleGlobalMouseUp = () => {
      if (viewerState.currentlyResizedElementId === props.shape.guid) {
        var _highlightElement$cur;

        updateState({
          currentlyResizedElementId: undefined
        });
        const newSize = props.onResized((_highlightElement$cur = highlightElement.current) === null || _highlightElement$cur === void 0 ? void 0 : _highlightElement$cur.getClientRects()[0]);

        if (highlightElement.current && newSize) {
          highlightElement.current.style.width = `${newSize.w * props.zoomRatio}px`;
          highlightElement.current.style.height = `${newSize.h * props.zoomRatio}px`;
        }
      }
    };

    document.addEventListener('mouseup', handleGlobalMouseUp);
    return () => {
      document.removeEventListener('mouseup', handleGlobalMouseUp);
    };
  }, [props, updateState, viewerState.currentlyResizedElementId]);
  (0, _react.useEffect)(() => {
    const mutationObserver = new MutationObserver(mutations => {
      mutations.forEach(mutation => {
        if (mutation.attributeName === 'style') {
          updateState({
            currentlyResizedElementId: props.shape.guid
          });
        }
      });
    });
    highlightElement.current && mutationObserver.observe(highlightElement.current, {
      attributes: true
    });
    return () => mutationObserver.disconnect();
  }, [props.shape.guid, updateState]);

  const onRightClick = event => {
    event.preventDefault();
    setAnchorEl(anchorEl ? null : event.currentTarget);
  };

  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement("div", {
    className: classes.root,
    tabIndex: 0,
    draggable: permissions.canEdit,
    onDragStart: props.onDragStart,
    onContextMenu: onRightClick,
    ref: highlightElement,
    style: {
      top: props.dimensions.top,
      left: props.dimensions.left,
      width: `${props.dimensions.width}px`,
      height: `${props.dimensions.height}px`
    }
  }), /*#__PURE__*/_react.default.createElement(_core.Popper, {
    id: id,
    open: open,
    anchorEl: anchorEl,
    placement: "right-start"
  }, /*#__PURE__*/_react.default.createElement(_core.ClickAwayListener, {
    onClickAway: () => setAnchorEl(null)
  }, /*#__PURE__*/_react.default.createElement(_core.Button, {
    variant: "contained",
    className: classes.button,
    onMouseUp: () => props.removeShape('highlights', props.shape.guid),
    startIcon: /*#__PURE__*/_react.default.createElement(_icons.Delete, {
      scale: props.zoomRatio
    })
  }, localization.delete))));
};

exports.ShapeHighlight = ShapeHighlight;
//# sourceMappingURL=shape-highlight.js.map