"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ShapeRedaction = ShapeRedaction;

var _core = require("@material-ui/core");

var _icons = require("@material-ui/icons");

var _react = _interopRequireWildcard(require("react"));

var _hooks = require("../../hooks");

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const useStyles = (0, _core.makeStyles)(theme => (0, _core.createStyles)({
  root: {
    position: 'absolute',
    resize: ({
      permissions,
      rotationDegree
    }) => permissions.canEdit && rotationDegree === 0 ? 'both' : 'none',
    overflow: 'auto',
    backgroundColor: 'black'
  },
  button: {
    backgroundColor: theme.palette.error.light
  }
}));
/**
 * Return a styled redaction component
 * @param shape Shape attributes
 * @param permissions Permissions of the current user
 * @param dimensions Shape dimensions
 * @param zoomRatio Zoom ratio
 * @param onDragStart Function triggered on drag event
 * @param onResized Function triggered on resized event
 * @param removeShape Function triggered on delete
 * @returns styled redaction component
 */

function ShapeRedaction({
  shape,
  permissions,
  dimensions,
  zoomRatio,
  onDragStart,
  onResized,
  removeShape,
  rotationDegree
}) {
  const classes = useStyles({
    shape,
    permissions,
    dimensions,
    zoomRatio,
    onDragStart,
    onResized,
    removeShape,
    rotationDegree
  });
  const localization = (0, _hooks.useLocalization)();
  const [anchorEl, setAnchorEl] = (0, _react.useState)(null);
  const open = Boolean(anchorEl);
  const id = open ? 'redaction-delete' : undefined;
  const redactionElement = (0, _react.useRef)(null);
  const viewerState = (0, _hooks.useViewerState)();
  const {
    updateState
  } = viewerState;
  (0, _react.useEffect)(() => {
    const handleGlobalMouseUp = () => {
      if (viewerState.currentlyResizedElementId === shape.guid) {
        var _redactionElement$cur;

        updateState({
          currentlyResizedElementId: undefined
        });
        const newSize = onResized((_redactionElement$cur = redactionElement.current) === null || _redactionElement$cur === void 0 ? void 0 : _redactionElement$cur.getClientRects()[0]);

        if (redactionElement.current && newSize) {
          redactionElement.current.style.width = `${newSize.w * zoomRatio}px`;
          redactionElement.current.style.height = `${newSize.h * zoomRatio}px`;
        }
      }
    };

    document.addEventListener('mouseup', handleGlobalMouseUp);
    return () => {
      document.removeEventListener('mouseup', handleGlobalMouseUp);
    };
  }, [onResized, shape.guid, updateState, viewerState.currentlyResizedElementId, zoomRatio]);
  (0, _react.useEffect)(() => {
    const mutationObserver = new MutationObserver(mutations => {
      mutations.forEach(mutation => {
        if (mutation.attributeName === 'style') {
          updateState({
            currentlyResizedElementId: shape.guid
          });
        }
      });
    });
    redactionElement.current && mutationObserver.observe(redactionElement.current, {
      attributes: true
    });
    return () => mutationObserver.disconnect();
  }, [shape.guid, updateState]);

  const onRightClick = event => {
    event.preventDefault();
    setAnchorEl(anchorEl ? null : event.currentTarget);
  };

  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement("div", {
    className: classes.root,
    tabIndex: 0,
    key: `r-${shape.h}-${shape.w}`,
    draggable: permissions.canEdit,
    onDragStart: onDragStart,
    onContextMenu: onRightClick,
    ref: redactionElement,
    style: {
      top: dimensions.top,
      left: dimensions.left,
      width: `${dimensions.width}px`,
      height: `${dimensions.height}px`
    }
  }), /*#__PURE__*/_react.default.createElement(_core.Popper, {
    id: id,
    open: open,
    anchorEl: anchorEl,
    placement: "right-start"
  }, /*#__PURE__*/_react.default.createElement(_core.ClickAwayListener, {
    onClickAway: () => setAnchorEl(null)
  }, /*#__PURE__*/_react.default.createElement(_core.Button, {
    variant: "contained",
    className: classes.button,
    onMouseUp: () => removeShape('redactions', shape.guid),
    startIcon: /*#__PURE__*/_react.default.createElement(_icons.Delete, {
      scale: zoomRatio
    })
  }, localization.delete))));
}
//# sourceMappingURL=shape-redaction.js.map