"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ShapeSkeleton = void 0;

var _react = _interopRequireWildcard(require("react"));

var _ = require("../..");

var _hooks = require("../../hooks");

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const ShapeSkeleton = props => {
  const permissions = (0, _.useDocumentPermissions)();
  const viewerState = (0, _hooks.useViewerState)();
  const [focused, setFocused] = (0, _react.useState)(false);
  /**
   * Method that returns the shape dimensions as CSS properties
   * @param shape the shape instance
   * @param offsetX optional X offset
   * @param offsetY optional Y offset
   */

  const getShapeDimensions = (shape, offsetX = 0, offsetY = 0) => {
    return {
      top: shape.y * props.zoomRatio + offsetY * props.zoomRatio,
      left: shape.x * props.zoomRatio + offsetX * props.zoomRatio,
      width: shape.w * props.zoomRatio,
      height: shape.h * props.zoomRatio
    };
  };
  /** event that will be triggered on resize */


  const onResized = clientRect => {
    if (clientRect && (viewerState.boxPosition.bottom || viewerState.boxPosition.left || viewerState.boxPosition.right || viewerState.boxPosition.top)) {
      const {
        shape,
        shapeType,
        zoomRatio
      } = props;
      const newSize = {
        w: clientRect.right < viewerState.pagesRects[props.visiblePagesIndex].pageRect.right && clientRect.right < viewerState.boxPosition.right ? clientRect.width / zoomRatio : (Math.min(viewerState.pagesRects[props.visiblePagesIndex].pageRect.right, viewerState.boxPosition.right) - clientRect.x) / zoomRatio,
        h: clientRect.bottom < viewerState.pagesRects[props.visiblePagesIndex].pageRect.bottom && clientRect.height < viewerState.boxPosition.bottom ? clientRect.height / zoomRatio : (Math.min(viewerState.pagesRects[props.visiblePagesIndex].pageRect.bottom, viewerState.boxPosition.bottom) - clientRect.y) / zoomRatio
      };
      props.updateShapeData(shapeType, shape.guid, { ...shape,
        w: newSize.w,
        h: newSize.h
      }, true);
      return newSize;
    }

    return undefined;
  };
  /** onDragStart event handler for the Shape instance */


  const onDragStart = ev => {
    ev.dataTransfer.setData('shape', JSON.stringify({
      type: props.shapeType,
      shape: props.shape,
      offset: {
        width: ev.clientX - ev.currentTarget.getBoundingClientRect().left,
        height: ev.clientY - ev.currentTarget.getBoundingClientRect().top
      }
    }));
  };
  /** onKeyPress event handler for deleting shapes */


  const handleKeyPress = ev => {
    switch (ev.key) {
      case 'Backspace':
      case 'Delete':
        permissions.canEdit && props.removeShape(props.shapeType, props.shape.guid);
        break;

      default:
        break;
    }
  };
  /** onFocus event handler that updates the 'focused' property */


  const onFocus = () => {
    setFocused(true);
  };
  /** onBlur event handler that updates the 'focused' property */


  const onBlur = ev => {
    setFocused(false);

    if (props.shapeType === 'annotations') {
      var _ev$currentTarget$inn;

      props.updateShapeData('annotations', props.shape.guid, { ...props.shape,
        text: (_ev$currentTarget$inn = ev.currentTarget.innerText) === null || _ev$currentTarget$inn === void 0 ? void 0 : _ev$currentTarget$inn.trim()
      });
    }
  };

  return /*#__PURE__*/_react.default.createElement("div", {
    onClickCapture: ev => ev.stopPropagation(),
    style: {
      filter: focused ? 'contrast(.9) brightness(1.1)' : ''
    },
    onFocus: onFocus,
    onKeyUp: ev => props.shapeType !== 'annotations' && handleKeyPress(ev),
    onBlur: ev => props.rotationDegree === 0 && onBlur(ev)
  }, props.shapeType === 'annotations' ? /*#__PURE__*/_react.default.createElement(_.ShapeAnnotation, {
    shape: props.shape,
    zoomRatio: props.zoomRatio,
    onDragStart: ev => props.rotationDegree === 0 && onDragStart(ev),
    onResized: ev => {
      if (props.rotationDegree === 0) {
        return onResized(ev);
      } else {
        return undefined;
      }
    },
    getShapeDimensions: getShapeDimensions,
    updateShapeData: props.updateShapeData,
    removeShape: props.removeShape,
    rotationDegree: props.rotationDegree
  }) : props.shapeType === 'redactions' ? /*#__PURE__*/_react.default.createElement(_.ShapeRedaction, {
    zoomRatio: props.zoomRatio,
    removeShape: props.removeShape,
    shape: props.shape,
    onDragStart: ev => props.rotationDegree === 0 && onDragStart(ev),
    onResized: ev => {
      if (props.rotationDegree === 0) {
        return onResized(ev);
      } else {
        return undefined;
      }
    },
    permissions: permissions,
    dimensions: getShapeDimensions(props.shape),
    rotationDegree: props.rotationDegree
  }) : /*#__PURE__*/_react.default.createElement(_.ShapeHighlight, {
    zoomRatio: props.zoomRatio,
    removeShape: props.removeShape,
    shape: props.shape,
    onDragStart: ev => props.rotationDegree === 0 && onDragStart(ev),
    onResized: ev => {
      if (props.rotationDegree === 0) {
        return onResized(ev);
      } else {
        return undefined;
      }
    },
    dimensions: getShapeDimensions(props.shape),
    rotationDegree: props.rotationDegree
  }));
};

exports.ShapeSkeleton = ShapeSkeleton;
//# sourceMappingURL=shape-skeleton.js.map