"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ShapesWidget = void 0;

var _clientUtils = require("@sensenet/client-utils");

var _core = require("@material-ui/core");

var _react = _interopRequireWildcard(require("react"));

var _hooks = require("../../hooks");

var _services = require("../../services");

var _shapes = require("../shapes");

var _commentMarker = require("./comment-marker");

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const useStyles = (0, _core.makeStyles)(() => {
  return (0, _core.createStyles)({
    shapesContainer: {
      position: 'absolute',
      top: 0,
      left: 0,
      width: '100%',
      height: '100%',
      zIndex: 1
    }
  });
});
/**
 * Defined the component's own properties
 */

/**
 * Page widget component for displaying shapes on a page
 */
const ShapesWidget = props => {
  var _viewerState$rotation, _viewerState$rotation2, _commentState$draft, _props$page;

  const classes = useStyles();
  const permissions = (0, _hooks.useDocumentPermissions)();
  const viewerState = (0, _hooks.useViewerState)();
  const {
    documentData,
    updateDocumentData
  } = (0, _hooks.useDocumentData)();
  const comments = (0, _hooks.useComments)();
  const commentState = (0, _hooks.useCommentState)();
  const shapesContainerRef = (0, _react.useRef)(null);
  const [resizeToken, setResizeToken] = (0, _react.useState)(0);
  const zoomRatio = props.imageRotation === 90 || props.imageRotation === 270 ? props.zoomRatioLying : props.zoomRatioStanding;
  const rotationDegree = ((_viewerState$rotation = viewerState.rotation) === null || _viewerState$rotation === void 0 ? void 0 : (_viewerState$rotation2 = _viewerState$rotation.find(rotation => rotation.pageNum === props.page.Index)) === null || _viewerState$rotation2 === void 0 ? void 0 : _viewerState$rotation2.degree) || 0;
  const visibleShapes = {
    redactions: (0, _services.applyShapeRotations)(documentData.shapes.redactions.filter(r => r.imageIndex === props.page.Index), rotationDegree, props.page),
    highlights: (0, _services.applyShapeRotations)(documentData.shapes.highlights.filter(r => r.imageIndex === props.page.Index), rotationDegree, props.page),
    annotations: (0, _services.applyShapeRotations)(documentData.shapes.annotations.filter(r => r.imageIndex === props.page.Index), rotationDegree, props.page)
  };
  const visibleComments = [...comments.comments.filter(comment => comment.page === props.page.Index), ...(props.page.Index !== undefined && ((_commentState$draft = commentState.draft) === null || _commentState$draft === void 0 ? void 0 : _commentState$draft.page) === ((_props$page = props.page) === null || _props$page === void 0 ? void 0 : _props$page.Index) ? [commentState.draft] : [])];
  const {
    updateState
  } = viewerState;
  const requestResize = (0, _react.useCallback)((0, _clientUtils.debounce)(() => {
    setResizeToken(Math.random());
  }, 300), []);
  const onScroll = (0, _react.useCallback)(() => {
    requestResize();
  }, [requestResize]);
  (0, _react.useEffect)(() => {
    const currentViewport = props.pageContainerRef;
    currentViewport === null || currentViewport === void 0 ? void 0 : currentViewport.addEventListener('scroll', onScroll);
    return () => currentViewport === null || currentViewport === void 0 ? void 0 : currentViewport.removeEventListener('scroll', onScroll);
  }, [onScroll, props.pageContainerRef]);
  (0, _react.useEffect)(() => {
    if (shapesContainerRef.current && props.visiblePagesIndex !== undefined) {
      const updatePagesRectsFunc = previous => {
        const clonePagesRects = [...previous.pagesRects];

        if (clonePagesRects.length === 0) {
          clonePagesRects.push({
            visiblePage: props.visiblePagesIndex,
            pageRect: shapesContainerRef.current.getClientRects()[0]
          });
        } else {
          const findIndex = clonePagesRects.findIndex(item => item.visiblePage === props.visiblePagesIndex);

          if (findIndex !== -1) {
            clonePagesRects[findIndex].pageRect = shapesContainerRef.current.getClientRects()[0];
          } else {
            clonePagesRects.push({
              visiblePage: props.visiblePagesIndex,
              pageRect: shapesContainerRef.current.getClientRects()[0]
            });
          }
        }

        return {
          pagesRects: clonePagesRects
        };
      };

      updateState(updatePagesRectsFunc);

      if (props.pageContainerRef && props.pageContainerRef.getClientRects().length > 0) {
        updateState({
          boxPosition: {
            bottom: props.pageContainerRef.getClientRects()[0].bottom,
            left: props.pageContainerRef.getClientRects()[0].left,
            right: props.pageContainerRef.getClientRects()[0].right,
            top: props.pageContainerRef.getClientRects()[0].top
          }
        });
      }
    }
  }, [resizeToken, props.pageContainerRef, props.visiblePagesIndex, updateState]);
  const removeShape = (0, _react.useCallback)((shapeType, guid) => {
    ;
    documentData.shapes[shapeType] = documentData.shapes[shapeType].filter(s => s.guid !== guid);
    updateDocumentData(documentData);
    viewerState.updateState({
      hasChanges: true
    });
  }, [documentData, updateDocumentData, viewerState]);
  const updateShapeData = (0, _react.useCallback)((shapeType, guid, shapeChange, force) => {
    const newDocumentData = { ...documentData
    };
    newDocumentData.shapes[shapeType] = newDocumentData.shapes[shapeType].map(s => {
      if (s.guid === guid) {
        return { ...s,
          ...shapeChange
        };
      }

      return s;
    });
    updateDocumentData(newDocumentData, force);
    viewerState.updateState({
      hasChanges: true
    });
  }, [documentData, updateDocumentData, viewerState]);
  const onDrop = (0, _react.useCallback)(ev => {
    if (permissions.canEdit && ev.dataTransfer.getData('shape') && (viewerState.boxPosition.bottom || viewerState.boxPosition.left || viewerState.boxPosition.right || viewerState.boxPosition.top)) {
      ev.preventDefault();
      const shapeData = JSON.parse(ev.dataTransfer.getData('shape'));
      const clientRect = ev.currentTarget.getClientRects()[0];

      const compareNumbers = (a, b) => a - b;

      const pageBoundings = {
        left: Math.max(viewerState.pagesRects[props.visiblePagesIndex].pageRect.left, viewerState.boxPosition.left),
        right: Math.min(viewerState.pagesRects[props.visiblePagesIndex].pageRect.right, viewerState.boxPosition.right) - shapeData.shape.w * zoomRatio,
        bottom: Math.min(viewerState.pagesRects[props.visiblePagesIndex].pageRect.bottom, viewerState.boxPosition.bottom) - shapeData.shape.h * zoomRatio,
        top: Math.max(viewerState.pagesRects[props.visiblePagesIndex].pageRect.top, viewerState.boxPosition.top)
      };
      const newX = [pageBoundings.left, pageBoundings.right, ev.pageX - shapeData.offset.width].sort(compareNumbers)[1] - clientRect.left;
      const newY = [pageBoundings.top, pageBoundings.bottom, ev.pageY - shapeData.offset.height].sort(compareNumbers)[1] - clientRect.top;
      updateShapeData(shapeData.type, shapeData.shape.guid, { ...shapeData.shape,
        imageIndex: props.page.Index,
        x: newX / zoomRatio,
        y: newY / zoomRatio
      }, true);
    }
  }, [permissions.canEdit, props.page.Index, props.visiblePagesIndex, updateShapeData, viewerState.boxPosition.bottom, viewerState.boxPosition.left, viewerState.boxPosition.right, viewerState.boxPosition.top, viewerState.pagesRects, zoomRatio]);
  return /*#__PURE__*/_react.default.createElement("div", {
    ref: shapesContainerRef,
    className: classes.shapesContainer,
    onDrop: onDrop,
    onDragOver: ev => ev.preventDefault()
  }, viewerState.showComments && visibleComments.length > 0 && visibleComments.map(marker => {
    var _viewerState$rotation3, _viewerState$rotation4;

    return /*#__PURE__*/_react.default.createElement(_commentMarker.CommentMarker, {
      isSelected: marker.id === commentState.activeCommentId,
      zoomRatio: zoomRatio,
      marker: marker,
      key: marker.id,
      rotation: _services.ImageUtil.normalizeDegrees(((_viewerState$rotation3 = viewerState.rotation) === null || _viewerState$rotation3 === void 0 ? void 0 : (_viewerState$rotation4 = _viewerState$rotation3.find(rotation => rotation.pageNum === props.page.Index)) === null || _viewerState$rotation4 === void 0 ? void 0 : _viewerState$rotation4.degree) || 0)
    });
  }), /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, permissions.canHideRedaction && viewerState.showRedaction && visibleShapes.redactions.map(redaction => {
    return /*#__PURE__*/_react.default.createElement(_shapes.ShapeSkeleton, {
      key: redaction.guid,
      shape: redaction,
      shapeType: "redactions",
      zoomRatio: zoomRatio,
      updateShapeData: updateShapeData,
      removeShape: removeShape,
      rotationDegree: rotationDegree,
      visiblePagesIndex: props.visiblePagesIndex
    });
  }), viewerState.showShapes && visibleShapes.annotations.map(annotation => {
    return /*#__PURE__*/_react.default.createElement(_shapes.ShapeSkeleton, {
      key: annotation.guid,
      shape: annotation,
      shapeType: "annotations",
      zoomRatio: zoomRatio,
      updateShapeData: updateShapeData,
      removeShape: removeShape,
      rotationDegree: rotationDegree,
      visiblePagesIndex: props.visiblePagesIndex
    });
  }), viewerState.showShapes && visibleShapes.highlights.map(highlight => {
    return /*#__PURE__*/_react.default.createElement(_shapes.ShapeSkeleton, {
      key: highlight.guid,
      shape: highlight,
      shapeType: "highlights",
      zoomRatio: zoomRatio,
      updateShapeData: updateShapeData,
      removeShape: removeShape,
      rotationDegree: rotationDegree,
      visiblePagesIndex: props.visiblePagesIndex
    });
  })));
};

exports.ShapesWidget = ShapesWidget;
//# sourceMappingURL=shapes.js.map