"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Thumbnails = void 0;

var _core = require("@material-ui/core");

var _react = _interopRequireWildcard(require("react"));

var _viewerState = require("../context/viewer-state");

var _hooks = require("../hooks");

var _services = require("../services");

var _ = require("./");

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const useStyles = (0, _core.makeStyles)(() => {
  return (0, _core.createStyles)({
    grid: {
      flexGrow: 1,
      flexShrink: 1,
      overflow: 'auto'
    },
    thumbnailsWrapper: {
      display: 'flex',
      flexDirection: 'column',
      justifyContent: 'center',
      alignItems: 'center'
    }
  });
});
/**
 * Defines the own properties for the PageList component
 */

const Thumbnails = props => {
  const classes = useStyles();
  const [marginTop, setMarginTop] = (0, _react.useState)(0);
  const [marginBottom, setMarginBottom] = (0, _react.useState)(0);
  const [visiblePages, setVisiblePages] = (0, _react.useState)([]);
  const [scrollState, setScrollState] = (0, _react.useState)(0);
  const viewportElement = (0, _react.useRef)();
  const viewerState = (0, _hooks.useViewerState)();
  const [resizeToken, setResizeToken] = (0, _react.useState)(0);
  const [viewport, setViewport] = (0, _react.useState)({
    width: 0,
    height: 0
  });
  const pages = (0, _hooks.usePreviewImages)();
  const requestResize = (0, _react.useCallback)(() => {
    setResizeToken(Math.random());
  }, []);
  const onScroll = (0, _react.useCallback)(() => {
    requestResize();
    setScrollState(viewportElement.current && viewportElement.current.scrollTop || 0);
  }, [requestResize]);
  (0, _react.useEffect)(() => {
    const currentViewport = viewportElement.current;

    if (currentViewport) {
      currentViewport.addEventListener('scroll', onScroll);
    }

    return () => currentViewport && currentViewport.removeEventListener('scroll', onScroll);
  }, [onScroll, viewportElement]);
  (0, _react.useEffect)(() => {
    window.addEventListener('resize', requestResize);
    return () => window.removeEventListener('resize', requestResize);
  }, [requestResize]);
  (0, _react.useEffect)(() => {
    if (viewportElement && viewportElement.current) {
      const newHeight = viewportElement.current.clientHeight - _.THUMBNAIL_PADDING * 2;
      const newWidth = viewportElement.current.clientWidth - _.THUMBNAIL_PADDING * 2;
      setViewport({
        height: newHeight >= 0 ? newHeight : 0,
        width: newWidth >= 0 ? newWidth : 0
      });
    }
  }, [resizeToken, viewportElement]);
  (0, _react.useEffect)(() => {
    if (!pages.imageData.length) {
      return;
    }

    let defaultWidth;
    let defaultHeight;

    const _visiblePages = pages.imageData.map(p => {
      var _viewerState$rotation, _viewerState$rotation2;

      if (p && !defaultWidth || !defaultHeight) {
        ;
        [defaultWidth, defaultHeight] = [p.Width, p.Height];
      }

      if (!p.Width || !p.Height) {
        ;
        [p.Width, p.Height] = [defaultWidth, defaultHeight];
      }

      const relativeSize = _services.ImageUtil.getImageSize({
        width: viewport.width,
        height: viewport.height
      }, {
        width: p.Width,
        height: p.Height,
        rotation: ((_viewerState$rotation = viewerState.rotation) === null || _viewerState$rotation === void 0 ? void 0 : (_viewerState$rotation2 = _viewerState$rotation.find(rotation => rotation.pageNum === p.Index)) === null || _viewerState$rotation2 === void 0 ? void 0 : _viewerState$rotation2.degree) || 0
      }, _viewerState.DEFAULT_ZOOM_LEVEL);

      return { ...p,
        Width: relativeSize.width,
        Height: relativeSize.height
      };
    });

    let _marginTop = 0;
    let _pagesToSkip = 0;

    while (_visiblePages[_pagesToSkip] && _marginTop + _visiblePages[_pagesToSkip].Height < scrollState) {
      _marginTop += _visiblePages[_pagesToSkip].Height + _.THUMBNAIL_PADDING * 2;
      _pagesToSkip++;
    }

    let _pagesToTake = 1;
    let _pagesHeight = 0;

    while (_visiblePages[_pagesToSkip + _pagesToTake] && _pagesHeight < viewport.height) {
      _pagesHeight += _visiblePages[_pagesToSkip + _pagesToTake].Height + _.THUMBNAIL_PADDING * 2;
      _pagesToTake++;
    }

    let _marginBottom = 0;

    for (let i = _pagesToSkip + _pagesToTake - 1; i < _visiblePages.length - 1; i++) {
      _marginBottom += _visiblePages[i].Height + _.THUMBNAIL_PADDING * 2;
    }

    setMarginTop(_marginTop);
    setMarginBottom(_marginBottom);

    const newVisiblePages = _visiblePages.slice(_pagesToSkip, _pagesToSkip + _pagesToTake);

    setVisiblePages(newVisiblePages);
  }, [pages.imageData, scrollState, viewerState, viewport.height, viewport.width]);
  return /*#__PURE__*/_react.default.createElement(_core.Grid, {
    item: true,
    className: classes.grid,
    id: _.THUMBNAIL_CONTAINER_ID,
    innerRef: viewportElement
  }, /*#__PURE__*/_react.default.createElement("div", {
    className: classes.thumbnailsWrapper,
    style: {
      paddingTop: marginTop || 0,
      paddingBottom: marginBottom || 0
    }
  }, visiblePages.map(page => /*#__PURE__*/_react.default.createElement(_.ThumbnailPage, {
    key: page.Index,
    page: page,
    viewportWidth: viewport.width,
    viewportHeight: viewport.height,
    onClick: () => props.onPageClick(page.Index)
  }))));
};

exports.Thumbnails = Thumbnails;
//# sourceMappingURL=thumbnails.js.map