"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.DocumentViewerApiSettingsProvider = exports.createDefaultApiSettings = exports.DocumentViewerApiSettingsContext = void 0;

var _clientUtils = require("@sensenet/client-utils");

var _hooksReact = require("@sensenet/hooks-react");

var _react = _interopRequireWildcard(require("react"));

var _uuid = require("uuid");

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

/**
 * Adds a globally unique ID to the shape
 */
const addGuidToShape = shape => {
  shape.guid = (0, _uuid.v1)();
  return shape;
};
/**
 * Concatenates avatar url with host
 * @param {DocumentData} documentData
 */


function changeCreatedByUrlToCurrent(documentData) {
  return comment => {
    return { ...comment,
      createdBy: { ...comment.createdBy,
        avatarUrl: `${documentData.hostName}${comment.createdBy.avatarUrl}`
      }
    };
  };
}

const DocumentViewerApiSettingsContext = /*#__PURE__*/(0, _react.createContext)({
  canEditDocument: async () => false,
  canHideRedaction: async () => false,
  canHideWatermark: async () => false,
  commentActions: {
    addPreviewComment: async ({
      comment
    }) => ({ ...comment
    }),
    deletePreviewComment: async () => ({
      modified: false
    }),
    getPreviewComments: async () => []
  },
  getDocumentData: async () => ({
    documentName: 'example',
    documentType: '',
    fileSizekB: 3,
    hostName: '',
    idOrPath: 1,
    pageNum: 1,
    pageCount: 0,
    shapes: {
      annotations: [],
      highlights: [],
      redactions: []
    }
  }),
  getExistingPreviewImages: async () => [],
  isPreviewAvailable: async () => ({
    Height: 0,
    Width: 0,
    Index: 0
  }),
  regeneratePreviews: async () => ({
    PageCount: -1,
    PreviewCount: 0
  }),
  saveChanges: async () => undefined
});
exports.DocumentViewerApiSettingsContext = DocumentViewerApiSettingsContext;

const createDefaultApiSettings = repo => ({
  regeneratePreviews: async ({
    document,
    abortController
  }) => {
    return await repo.preview.regenerate({
      idOrPath: document.idOrPath,
      abortController
    });
  },
  saveChanges: async ({
    document,
    abortController
  }) => {
    const reqBody = {
      Shapes: JSON.stringify([{
        redactions: document.shapes.redactions
      }, {
        highlights: document.shapes.highlights
      }, {
        annotations: document.shapes.annotations
      }])
    };
    await repo.patch({
      idOrPath: document.idOrPath,
      content: reqBody,
      requestInit: {
        signal: abortController.signal
      }
    });
  },
  getDocumentData: async settings => {
    const documentData = (await repo.load({
      idOrPath: settings.idOrPath,
      oDataOptions: {
        select: 'all'
      }
    })).d;
    return {
      idOrPath: settings.idOrPath,
      hostName: repo.configuration.repositoryUrl,
      fileSizekB: documentData.Size,
      pageCount: (0, _clientUtils.toNumber)(documentData.PageCount, -1),
      documentName: documentData.DisplayName || '',
      documentType: documentData.Type || 'File',
      shapes: documentData.Shapes && {
        redactions: JSON.parse(documentData.Shapes)[0].redactions.map(a => addGuidToShape(a)) || [],
        annotations: JSON.parse(documentData.Shapes)[2].annotations.map(a => addGuidToShape(a)) || [],
        highlights: JSON.parse(documentData.Shapes)[1].highlights.map(a => addGuidToShape(a)) || []
      } || {
        redactions: [],
        annotations: [],
        highlights: []
      }
    };
  },
  isPreviewAvailable: async ({
    document,
    version,
    page,
    abortController
  }) => {
    return await repo.preview.available({
      document,
      version,
      page,
      abortController
    });
  },
  canEditDocument: async ({
    idOrPath,
    abortController
  }) => {
    const response = await repo.security.hasPermission(idOrPath, ['Save'], undefined, {
      signal: abortController.signal,
      credentials: 'include'
    });
    return response;
  },
  canHideRedaction: async ({
    idOrPath,
    abortController
  }) => await repo.security.hasPermission(idOrPath, ['PreviewWithoutRedaction'], undefined, {
    signal: abortController.signal,
    credentials: 'include'
  }),
  canHideWatermark: async ({
    idOrPath,
    abortController
  }) => await repo.security.hasPermission(idOrPath, ['PreviewWithoutWatermark'], undefined, {
    signal: abortController.signal,
    credentials: 'include'
  }),
  getExistingPreviewImages: async ({
    document,
    version,
    abortController
  }) => {
    return await repo.preview.getExistingImages({
      document,
      version,
      abortController
    });
  },
  commentActions: {
    addPreviewComment: async ({
      document,
      comment,
      abortController
    }) => {
      const response = await repo.preview.addComment({
        idOrPath: document.idOrPath,
        comment,
        abortController
      });
      return [response].map(changeCreatedByUrlToCurrent(document))[0];
    },
    deletePreviewComment: async ({
      document,
      commentId,
      abortController
    }) => {
      return await repo.preview.deleteComment({
        idOrPath: document.idOrPath,
        commentId,
        abortController
      });
    },
    getPreviewComments: async ({
      document,
      page,
      abortController
    }) => {
      const response = await repo.preview.getComments({
        idOrPath: document.idOrPath,
        page,
        abortController
      });
      return response.map(changeCreatedByUrlToCurrent(document));
    }
  }
});

exports.createDefaultApiSettings = createDefaultApiSettings;

const DocumentViewerApiSettingsProvider = ({
  children,
  options
}) => {
  const repo = (0, _hooksReact.useRepository)();
  const settings = (0, _react.useMemo)(() => (0, _clientUtils.deepMerge)(createDefaultApiSettings(repo), options), [repo, options]);
  return /*#__PURE__*/_react.default.createElement(DocumentViewerApiSettingsContext.Provider, {
    value: settings
  }, children);
};

exports.DocumentViewerApiSettingsProvider = DocumentViewerApiSettingsProvider;
//# sourceMappingURL=api-settings.js.map