"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.CommentsContextProvider = exports.CommentsContext = exports.defaultCommentsContext = void 0;

var _clientUtils = require("@sensenet/client-utils");

var _react = _interopRequireWildcard(require("react"));

var _hooks = require("../hooks");

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const defaultCommentsContext = {
  comments: [],
  addPreviewComment: async () => undefined,
  deletePreviewComment: async () => undefined,
  getPreviewComments: async () => undefined
};
exports.defaultCommentsContext = defaultCommentsContext;
const CommentsContext = /*#__PURE__*/(0, _react.createContext)(defaultCommentsContext);
exports.CommentsContext = CommentsContext;

const CommentsContextProvider = props => {
  const api = (0, _hooks.useDocumentViewerApi)();
  const {
    documentData
  } = (0, _hooks.useDocumentData)();
  const viewerState = (0, _hooks.useViewerState)();
  const [comments, setComments] = (0, _react.useState)([]);
  (0, _react.useEffect)(() => {
    const abortController = new AbortController();

    (async () => {
      if (viewerState.showComments) {
        const result = await api.commentActions.getPreviewComments({
          document: documentData,
          page: viewerState.activePage,
          abortController
        });
        setComments(result);
      }
    })();

    return () => abortController.abort();
  }, [api.commentActions, documentData, viewerState.activePage, viewerState.showComments]);
  (0, _react.useEffect)(() => {
    const disposables = [_clientUtils.Trace.method({
      object: api.commentActions,
      isAsync: true,
      methodName: 'addPreviewComment',
      method: api.commentActions.addPreviewComment,
      onFinished: async ({
        returned
      }) => {
        const a = await returned;
        setComments([...comments, a]);
        viewerState.updateState({
          isPlacingCommentMarker: false
        });
      }
    }), _clientUtils.Trace.method({
      object: api.commentActions,
      method: api.commentActions.deletePreviewComment,
      methodName: 'deletePreviewComment',
      isAsync: true,
      onFinished: async ({
        returned,
        methodArguments
      }) => {
        const returnedValue = await returned;

        if (returnedValue.modified) {
          setComments(comments.filter(c => c.id !== methodArguments[0].commentId));
        }
      }
    })];
    return () => disposables.forEach(d => d.dispose());
  }, [api.commentActions, comments, viewerState]);
  return /*#__PURE__*/_react.default.createElement(CommentsContext.Provider, {
    value: { ...api.commentActions,
      comments
    }
  }, props.children);
};

exports.CommentsContextProvider = CommentsContextProvider;
//# sourceMappingURL=comments.js.map