"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.DocumentDataProvider = exports.DocumentDataContext = exports.defaultDocumentDataContextValue = void 0;

var _clientUtils = require("@sensenet/client-utils");

var _hooksReact = require("@sensenet/hooks-react");

var _react = _interopRequireWildcard(require("react"));

var _semaphoreAsyncAwait = _interopRequireDefault(require("semaphore-async-await"));

var _components = require("../components");

var _enums = require("../enums");

var _hooks = require("../hooks");

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const defaultDocumentData = {
  documentName: '',
  documentType: '',
  fileSizekB: 0,
  hostName: '',
  idOrPath: 0,
  pageCount: _enums.PreviewState.Loading,
  shapes: {
    annotations: [],
    highlights: [],
    redactions: []
  },
  error: undefined
};
const defaultDocumentDataContextValue = {
  documentData: defaultDocumentData,
  updateDocumentData: () => undefined,
  isInProgress: false,
  triggerReload: () => {}
};
exports.defaultDocumentDataContextValue = defaultDocumentDataContextValue;
const DocumentDataContext = /*#__PURE__*/(0, _react.createContext)(defaultDocumentDataContextValue);
exports.DocumentDataContext = DocumentDataContext;

const DocumentDataProvider = ({
  children
}) => {
  const api = (0, _hooks.useDocumentViewerApi)();
  const doc = (0, _hooks.useViewerSettings)();
  const repo = (0, _hooksReact.useRepository)();
  const [documentData, setDocumentData] = (0, _react.useState)(defaultDocumentData);
  const [loadLock] = (0, _react.useState)(new _semaphoreAsyncAwait.default(1));
  const [isInProgress, setIsInProgress] = (0, _react.useState)(false);
  const [reloadToken, setReloadToken] = (0, _react.useState)(0);

  const triggerReload = () => setReloadToken(prevValue => prevValue + 1);

  (0, _react.useEffect)(() => {
    const ac = new AbortController();

    const getData = async () => {
      const result = await api.getDocumentData({
        hostName: repo.configuration.repositoryUrl,
        idOrPath: doc.documentIdOrPath,
        version: doc.version,
        abortController: ac
      });

      if (result.pageCount === _enums.PreviewState.Loading && ac.signal.aborted === false) {
        setDocumentData(result);
        await (0, _clientUtils.sleepAsync)(_components.POLLING_INTERVAL);
        getData();
      } else {
        setDocumentData(result);
      }
    };

    (async () => {
      try {
        setIsInProgress(true);
        await loadLock.acquire();
        await getData();
      } catch (error) {
        if (!ac.signal.aborted) {
          setDocumentData({ ...defaultDocumentData,
            pageCount: _enums.PreviewState.ClientFailure,
            error: error.toString()
          });
          throw error;
        }
      } finally {
        setIsInProgress(false);
        loadLock.release();
      }
    })();

    return () => ac.abort();
  }, [api, doc.documentIdOrPath, doc.version, loadLock, repo.configuration.repositoryUrl, reloadToken]);
  const updateDocumentData = (0, _react.useCallback)((newDocData, force) => {
    const merged = (0, _clientUtils.deepMerge)(documentData, newDocData);
    force ? setDocumentData(merged) : JSON.stringify(documentData) !== JSON.stringify(merged) && setDocumentData(merged);
  }, [documentData]);

  if (!documentData.idOrPath) {
    return null;
  }

  return /*#__PURE__*/_react.default.createElement(DocumentDataContext.Provider, {
    value: {
      documentData,
      updateDocumentData,
      isInProgress,
      triggerReload
    }
  }, children);
};

exports.DocumentDataProvider = DocumentDataProvider;
//# sourceMappingURL=document-data.js.map