"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.DocumentPermissionsContextProvider = exports.DocumentPermissionsContext = void 0;

var _react = _interopRequireWildcard(require("react"));

var _hooks = require("../hooks");

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const DocumentPermissionsContext = /*#__PURE__*/(0, _react.createContext)({
  canEdit: false,
  canHideRedaction: false,
  canHideWatermark: false
});
exports.DocumentPermissionsContext = DocumentPermissionsContext;

const DocumentPermissionsContextProvider = ({
  children
}) => {
  const {
    documentData
  } = (0, _hooks.useDocumentData)();
  const api = (0, _hooks.useDocumentViewerApi)();
  const [canEdit, setcanEdit] = (0, _react.useState)(false);
  const [canHideRedaction, setcanHideRedaction] = (0, _react.useState)(false);
  const [canHideWatermark, setcanHideWatermark] = (0, _react.useState)(false);
  const documentIdOrPath = documentData.idOrPath;
  (0, _react.useEffect)(() => {
    const abortController = new AbortController();

    (async () => {
      try {
        const canEditPromise = api.canEditDocument({
          idOrPath: documentIdOrPath,
          abortController
        });
        const cancanHideRedactionPromise = api.canHideRedaction({
          idOrPath: documentIdOrPath,
          abortController
        });
        const canHideWatermarkPromise = api.canHideWatermark({
          idOrPath: documentIdOrPath,
          abortController
        });
        const [canEditValue, canHideRedactionValue, canHideWatermarkValue] = await Promise.all([canEditPromise, cancanHideRedactionPromise, canHideWatermarkPromise]);
        setcanEdit(canEditValue);
        setcanHideRedaction(canHideRedactionValue);
        setcanHideWatermark(canHideWatermarkValue);
      } catch (error) {
        if (!abortController.signal.aborted) {
          throw error;
        }
      }
    })();
  }, [api, documentIdOrPath]);
  return /*#__PURE__*/_react.default.createElement(DocumentPermissionsContext.Provider, {
    value: {
      canEdit,
      canHideRedaction,
      canHideWatermark
    }
  }, children);
};

exports.DocumentPermissionsContextProvider = DocumentPermissionsContextProvider;
//# sourceMappingURL=document-permissions.js.map