"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.PreviewImageDataContextProvider = exports.PreviewImageDataContext = void 0;

var _react = _interopRequireWildcard(require("react"));

var _enums = require("../enums");

var _hooks = require("../hooks");

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const PreviewImageDataContext = /*#__PURE__*/(0, _react.createContext)({
  imageData: [],
  setImageData: () => ({})
});
exports.PreviewImageDataContext = PreviewImageDataContext;

const PreviewImageDataContextProvider = props => {
  const viewerSettings = (0, _hooks.useViewerSettings)();
  const api = (0, _hooks.useDocumentViewerApi)();
  const {
    documentData
  } = (0, _hooks.useDocumentData)();
  const viewerState = (0, _hooks.useViewerState)();
  const [previewImages, setPreviewImages] = (0, _react.useState)([]);
  (0, _react.useEffect)(() => {
    const documentDataWithoutShapes = {
      hostName: documentData.hostName,
      idOrPath: documentData.idOrPath,
      documentName: documentData.documentName,
      documentType: documentData.documentType,
      fileSizekB: documentData.fileSizekB,
      pageCount: documentData.pageCount,
      error: documentData.error
    };

    if (documentData.pageCount <= _enums.PreviewState.Empty) {
      return;
    }

    const abortController = new AbortController();

    (async () => {
      try {
        setPreviewImages([]);
        const images = await api.getExistingPreviewImages({
          document: documentDataWithoutShapes,
          version: viewerSettings.version || '',
          showWatermark: viewerState.showWatermark,
          abortController
        });
        setPreviewImages(images);
      } catch (error) {
        if (!abortController.signal.aborted) {
          throw error;
        }
      }
    })();

    return () => abortController.abort();
  }, [api, documentData.documentName, documentData.documentType, documentData.error, documentData.fileSizekB, documentData.hostName, documentData.idOrPath, documentData.pageCount, viewerSettings.version, viewerState.showWatermark]);
  return /*#__PURE__*/_react.default.createElement(PreviewImageDataContext.Provider, {
    value: {
      imageData: previewImages,
      setImageData: setPreviewImages
    }
  }, props.children);
};

exports.PreviewImageDataContextProvider = PreviewImageDataContextProvider;
//# sourceMappingURL=preview-image-data.js.map