"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.usePreviewImage = void 0;

var _clientUtils = require("@sensenet/client-utils");

var _react = require("react");

var _documentViewer = require("../components/document-viewer");

var _ = require(".");

const usePreviewImage = pageNo => {
  const api = (0, _.useDocumentViewerApi)();
  const {
    documentData
  } = (0, _.useDocumentData)();
  const viewerSettings = (0, _.useViewerSettings)();
  const viewerState = (0, _.useViewerState)();
  const {
    imageData,
    setImageData
  } = (0, _.usePreviewImages)();
  const currentPageData = (0, _react.useMemo)(() => imageData.find(i => i.Index === pageNo), [imageData, pageNo]);
  (0, _react.useEffect)(() => {
    const abortController = new AbortController();

    const getPreviewImageData = async () => {
      try {
        const previewImageData = await api.isPreviewAvailable({
          abortController,
          document: documentData,
          page: pageNo,
          showWatermark: viewerState.showWatermark,
          version: viewerSettings.version
        });

        if (previewImageData !== null && previewImageData !== void 0 && previewImageData.PreviewAvailable) {
          if (previewImageData.PreviewImageUrl) {
            setImageData(previousValue => {
              const newImages = [...previousValue];
              const oldValueIndex = newImages.findIndex(image => image.Index === pageNo);

              if (oldValueIndex !== -1) {
                newImages[oldValueIndex] = { ...previewImageData,
                  Index: pageNo
                };
                return newImages;
              } else {
                newImages.push({ ...previewImageData,
                  Index: pageNo
                });
                return newImages;
              }
            });
          }
        } else {
          await (0, _clientUtils.sleepAsync)(_documentViewer.POLLING_INTERVAL);
          getPreviewImageData();
        }
      } catch (error) {
        if (!abortController.signal.aborted) {
          throw error;
        }
      }
    };

    if (currentPageData && !currentPageData.PreviewImageUrl) {
      getPreviewImageData();
    }

    return () => abortController.abort();
  }, [api, currentPageData, documentData, pageNo, setImageData, viewerSettings.version, viewerState.showWatermark]);
  return {
    context: setImageData,
    image: currentPageData
  };
};

exports.usePreviewImage = usePreviewImage;
//# sourceMappingURL=use-preview-image.js.map